Installing YARP                                                       {#install}
===============

Source for YARP are available from https://github.com/robotology/yarp.
Installing YARP is easy it can be done from sources or directly from binary
packages.

We provide in the links below detailed installation instructions for all
systems.

* \subpage install_yarp_linux
* \subpage install_yarp_windows
* \subpage install_yarp_mac

After your are done installing YARP you can proceed with the following link:
\subpage check_your_installation.
